"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLanguageService = exports.githubSlugifier = void 0;
const documentSymbols_1 = require("./languageFeatures/documentSymbols");
const folding_1 = require("./languageFeatures/folding");
const smartSelect_1 = require("./languageFeatures/smartSelect");
const tableOfContents_1 = require("./tableOfContents");
var slugify_1 = require("./slugify");
Object.defineProperty(exports, "githubSlugifier", { enumerable: true, get: function () { return slugify_1.githubSlugifier; } });
function createLanguageService(workspace, parser, logger) {
    const tocProvider = new tableOfContents_1.MdTableOfContentsProvider(parser, workspace, logger);
    const docSymbolProvider = new documentSymbols_1.MdDocumentSymbolProvider(tocProvider, logger);
    const smartSelectProvider = new smartSelect_1.MdSelectionRangeProvider(parser, tocProvider, logger);
    const foldingProvider = new folding_1.MdFoldingProvider(parser, tocProvider, logger);
    return Object.freeze({
        provideDocumentSymbols(document, _token) {
            return docSymbolProvider.provideDocumentSymbols(document);
        },
        provideFoldingRanges(document, token) {
            return foldingProvider.provideFoldingRanges(document, token);
        },
        provideSelectionRanges(document, positions, token) {
            return smartSelectProvider.provideSelectionRanges(document, positions, token);
        }
    });
}
exports.createLanguageService = createLanguageService;
